#!/usr/bin/env python
# coding=utf-8

import sys, math
sys.path.append('/usr/share/inkscape/extensions') # or another path, as necessary
import inkex
from simplestyle import *

class Abwicklung(inkex.Effect):
	"""
	Example Inkscape effect extension.
	Creates a new layer with a "Hello World!" text centered in the middle of the document.
	"""
	def __init__(self):
		"""
		Constructor.
		Defines the "--what" option of a script.
		"""
		# Call the base class constructor.
		inkex.Effect.__init__(self)

		# Define string option "--what" with "-w" shortcut and default value "World".
		self.OptionParser.add_option('-d', '--rohrdurchmesser', action = 'store',
			type = 'float', dest = 'rohrdurchmesser', default = '30',
			help = 'Rohrdurchmesser ...')
		self.OptionParser.add_option('-w', '--winkel', action = 'store',
			type = 'float', dest = 'winkel', default = '135',
			help = 'Winkel ...')
		self.OptionParser.add_option('', '--tab', action = 'store',
			type = 'string', dest = 'tab', default = 'global',
			help = '')  
			
	def addLine(self, x1, y1, x2, y2, grp, col=0):
	
		if col == 1:
			line_style   = { 'stroke': 'red',
								'stroke-width': '1' }
		else:
			line_style   = { 'stroke': 'black',
								'stroke-width': '1' }
		x1 = str(self.unittouu(str(x1)+"mm") )
		y1 = str(self.unittouu(str(y1)+"mm") )
		x2 = str(self.unittouu(str(x2)+"mm") )
		y2 = str(self.unittouu(str(y2)+"mm") )

		line_attribs = {'style' : formatStyle(line_style),
						inkex.addNS('label','inkscape') : 'name',
						'd' : 'M '+x1+','+y1+' L '+x2+','+y2}

		line = inkex.etree.SubElement(grp, inkex.addNS('path','svg'), line_attribs )




	def effect(self):
		rohrdurchmesser = self.options.rohrdurchmesser
		winkel = self.options.winkel
		paperwidth = rohrdurchmesser * math.pi
		y = math.fabs( math.tan((winkel-90) / 180 * math.pi) * rohrdurchmesser )
		
		paperheight = y * 2
		
		if paperheight < 200:
			paperheight = 200
		
		# Get access to main SVG document element and get its dimensions.
		svg = self.document.getroot()

		# Again, there are two ways to get the attributes:
		width  = self.unittouu(svg.get('width'))
		height = self.unittouu(svg.get('height'))
		
		# Create new group
		centre = self.view_center   #Put in in the centre of the current view
		#grp_transform = 'translate' + str( centre )
		grp_transform = 'translate (100 100)' 

		grp_name = 'Border'
		grp_attribs = {inkex.addNS('label','inkscape'):grp_name,
						'transform':grp_transform }
		grpBorder = inkex.etree.SubElement(self.current_layer, 'g', grp_attribs)
		
		grp_name = 'Cut'
		grp_attribs = {inkex.addNS('label','inkscape'):grp_name,
						'transform':grp_transform }
		grpCut = inkex.etree.SubElement(self.current_layer, 'g', grp_attribs)
		

		self.addLine(0, 0, paperwidth, 0, grpBorder, 0)
		self.addLine(paperwidth, 0, paperwidth, paperheight, grpBorder, 0)
		self.addLine(paperwidth, paperheight, 0, paperheight, grpBorder, 0)		
		self.addLine(0, paperheight, 0, 0, grpBorder, 0)
		
		for i in range(0, 359):
			x1 = (i+0) * math.pi * rohrdurchmesser / 360
			x2 = (i+1) * math.pi * rohrdurchmesser / 360
			y1 = - 0.5 * (math.cos(i * math.pi / 180) - 1) * y
			y2 = - 0.5 * (math.cos((i + 1) * math.pi / 180) - 1) * y
			self.addLine(x1, y1, x2, y2, grpCut, 1)
		
		
		

# Create effect instance and apply it.
effect = Abwicklung()
effect.affect()
